@@ -11,11 +11,11 @@ use strict;
 use warnings;
 
 package Dist::Metadata;
-# git description: v0.925-17-g08a6891
+# git description: v0.926-3-ge4f15df
 
 our $AUTHORITY = 'cpan:RWSTAUNER';
 # ABSTRACT: Information about a perl module distribution
-$Dist::Metadata::VERSION = '0.926';
+$Dist::Metadata::VERSION = '0.927';
 use Carp qw(croak carp);
 use CPAN::Meta 2.1 ();
 use List::Util qw(first);    # core in perl v5.7.3
@@ -289,9 +289,8 @@ __END__
 =encoding UTF-8
 
 =for :stopwords Randy Stauner ACKNOWLEDGEMENTS TODO dist dists dir unix checksum checksums
-David Jeffrey Ryan Sawyer Steinbrunner Thalhammer X cpan testmatrix url
-annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata
-placeholders metacpan
+cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc
+mailto metadata placeholders metacpan
 
 =head1 NAME
 
@@ -299,7 +298,9 @@ Dist::Metadata - Information about a perl module distribution
 
 =head1 VERSION
 
-version 0.926
+version 0.927
+
+=for test_synopsis my $path_to_archive;
 
 =head1 SYNOPSIS
 
@@ -535,8 +536,6 @@ X<version> version
 =for Pod::Coverage name version provides
 UNKNOWN
 
-=for test_synopsis my $path_to_archive;
-
 =head1 TODO
 
 =over 4
@@ -649,7 +648,7 @@ Randy Stauner <rwstauner@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords David Steinbrunner Jeffrey Ryan Thalhammer Sawyer X
+=for stopwords David Steinbrunner Graham Knop Jeffrey Ryan Thalhammer Sawyer X
 
 =over 4
 
@@ -659,6 +658,10 @@ David Steinbrunner <dsteinbrunner@pobox.com>
 
 =item *
 
+Graham Knop <haarg@haarg.org>
+
+=item *
+
 Jeffrey Ryan Thalhammer <thaljef@cpan.org>
 
 =item *
